@@ -5,13 +5,22 @@ describe 'sahara::db::sync' do
   shared_examples_for 'sahara-dbsync' do
 
     context 'default patameters' do
+
+      it { is_expected.to contain_class('sahara::deps') }
+
       it 'runs sahara-dbmanage' do
         is_expected.to contain_exec('sahara-dbmanage').with(
           :command     => 'sahara-db-manage --config-file /etc/sahara/sahara.conf upgrade head',
           :path        => '/usr/bin',
           :user        => 'sahara',
           :refreshonly => 'true',
+          :try_sleep   => 5,
+          :tries       => 10,
           :logoutput   => 'on_failure',
+          :subscribe   => ['Anchor[sahara::install::end]',
+                           'Anchor[sahara::config::end]',
+                           'Anchor[sahara::dbsync::begin]'],
+          :notify      => 'Anchor[sahara::dbsync::end]',
           :tag         => 'openstack-db',
         )
       end
@@ -30,7 +39,13 @@ describe 'sahara::db::sync' do
           :path        => '/usr/bin',
           :user        => 'sahara',
           :refreshonly => 'true',
+          :try_sleep   => 5,
+          :tries       => 10,
           :logoutput   => 'on_failure',
+          :subscribe   => ['Anchor[sahara::install::end]',
+                           'Anchor[sahara::config::end]',
+                           'Anchor[sahara::dbsync::begin]'],
+          :notify      => 'Anchor[sahara::dbsync::end]',
           :tag         => 'openstack-db',
         )
         }
